@@ -1,20 +1,17 @@
-'use strict'
+const protocol = require('./constants')
+const empty = Buffer.allocUnsafe(0)
+const zeroBuf = Buffer.from([0])
+const numbers = require('./numbers')
+const nextTick = require('process-nextick-args').nextTick
+const debug = require('debug')('mqtt-packet:writeToStream')
 
-var protocol = require('./constants')
-var Buffer = require('safe-buffer').Buffer
-var empty = Buffer.allocUnsafe(0)
-var zeroBuf = Buffer.from([0])
-var numbers = require('./numbers')
-var nextTick = require('process-nextick-args').nextTick
-var debug = require('debug')('mqtt-packet:writeToStream')
-
-var numCache = numbers.cache
-var generateNumber = numbers.generateNumber
-var generateCache = numbers.generateCache
-var genBufVariableByteInt = numbers.genBufVariableByteInt
-var generate4ByteBuffer = numbers.generate4ByteBuffer
-var writeNumber = writeNumberCached
-var toGenerate = true
+const numCache = numbers.cache
+const generateNumber = numbers.generateNumber
+const generateCache = numbers.generateCache
+const genBufVariableByteInt = numbers.genBufVariableByteInt
+const generate4ByteBuffer = numbers.generate4ByteBuffer
+let writeNumber = writeNumberCached
+let toGenerate = true
 
 function generate (packet, stream, opts) {
   debug('generate called')
@@ -65,10 +62,10 @@ function generate (packet, stream, opts) {
  * Set to "false" to allocate buffers on-the-flight instead of pre-generated cache
  */
 Object.defineProperty(generate, 'cacheNumbers', {
-  get: function () {
+  get () {
     return writeNumber === writeNumberCached
   },
-  set: function (value) {
+  set (value) {
     if (value) {
       if (!numCache || Object.keys(numCache).length === 0) toGenerate = true
       writeNumber = writeNumberCached
@@ -84,21 +81,21 @@ function uncork (stream) {
 }
 
 function connect (packet, stream, opts) {
-  var settings = packet || {}
-  var protocolId = settings.protocolId || 'MQTT'
-  var protocolVersion = settings.protocolVersion || 4
-  var will = settings.will
-  var clean = settings.clean
-  var keepalive = settings.keepalive || 0
-  var clientId = settings.clientId || ''
-  var username = settings.username
-  var password = settings.password
+  const settings = packet || {}
+  const protocolId = settings.protocolId || 'MQTT'
+  const protocolVersion = settings.protocolVersion || 4
+  const will = settings.will
+  let clean = settings.clean
+  const keepalive = settings.keepalive || 0
+  const clientId = settings.clientId || ''
+  const username = settings.username
+  const password = settings.password
   /* mqtt5 new oprions */
-  var properties = settings.properties
+  const properties = settings.properties
 
   if (clean === undefined) clean = true
 
-  var length = 0
+  let length = 0
 
   // Must be a string and non-falsy
   if (!protocolId ||
@@ -186,7 +183,7 @@ function connect (packet, stream, opts) {
   }
 
   // Username
-  var providedUsername = false
+  let providedUsername = false
   if (username != null) {
     if (isStringOrBuffer(username)) {
       providedUsername = true
@@ -229,7 +226,7 @@ function connect (packet, stream, opts) {
   )
 
   // Connect flags
-  var flags = 0
+  let flags = 0
   flags |= (username != null) ? protocol.USERNAME_MASK : 0
   flags |= (password != null) ? protocol.PASSWORD_MASK : 0
   flags |= (will && will.retain) ? protocol.WILL_RETAIN_MASK : 0
@@ -272,11 +269,11 @@ function connect (packet, stream, opts) {
 }
 
 function connack (packet, stream, opts) {
-  var version = opts ? opts.protocolVersion : 4
-  var settings = packet || {}
-  var rc = version === 5 ? settings.reasonCode : settings.returnCode
-  var properties = settings.properties
-  var length = 2 // length of rc and sessionHeader
+  const version = opts ? opts.protocolVersion : 4
+  const settings = packet || {}
+  const rc = version === 5 ? settings.reasonCode : settings.returnCode
+  const properties = settings.properties
+  let length = 2 // length of rc and sessionHeader
 
   // Check return code
   if (typeof rc !== 'number') {
@@ -284,7 +281,7 @@ function connack (packet, stream, opts) {
     return false
   }
   // mqtt5 properties
-  var propertiesData = null
+  let propertiesData = null
   if (version === 5) {
     propertiesData = getProperties(stream, properties)
     if (!propertiesData) { return false }
@@ -305,16 +302,16 @@ function connack (packet, stream, opts) {
 
 function publish (packet, stream, opts) {
   debug('publish: packet: %o', packet)
-  var version = opts ? opts.protocolVersion : 4
-  var settings = packet || {}
-  var qos = settings.qos || 0
-  var retain = settings.retain ? protocol.RETAIN_MASK : 0
-  var topic = settings.topic
-  var payload = settings.payload || empty
-  var id = settings.messageId
-  var properties = settings.properties
+  const version = opts ? opts.protocolVersion : 4
+  const settings = packet || {}
+  const qos = settings.qos || 0
+  const retain = settings.retain ? protocol.RETAIN_MASK : 0
+  const topic = settings.topic
+  const payload = settings.payload || empty
+  const id = settings.messageId
+  const properties = settings.properties
 
-  var length = 0
+  let length = 0
 
   // Topic must be a non-empty string or Buffer
   if (typeof topic === 'string') length += Buffer.byteLength(topic) + 2
@@ -335,7 +332,7 @@ function publish (packet, stream, opts) {
   } else if (qos) length += 2
 
   // mqtt5 properties
-  var propertiesData = null
+  let propertiesData = null
   if (version === 5) {
     propertiesData = getProperties(stream, properties)
     if (!propertiesData) { return false }
@@ -367,15 +364,15 @@ function publish (packet, stream, opts) {
 
 /* Puback, pubrec, pubrel and pubcomp */
 function confirmation (packet, stream, opts) {
-  var version = opts ? opts.protocolVersion : 4
-  var settings = packet || {}
-  var type = settings.cmd || 'puback'
-  var id = settings.messageId
-  var dup = (settings.dup && type === 'pubrel') ? protocol.DUP_MASK : 0
-  var qos = 0
-  var reasonCode = settings.reasonCode
-  var properties = settings.properties
-  var length = version === 5 ? 3 : 2
+  const version = opts ? opts.protocolVersion : 4
+  const settings = packet || {}
+  const type = settings.cmd || 'puback'
+  const id = settings.messageId
+  const dup = (settings.dup && type === 'pubrel') ? protocol.DUP_MASK : 0
+  let qos = 0
+  const reasonCode = settings.reasonCode
+  const properties = settings.properties
+  let length = version === 5 ? 3 : 2
 
   if (type === 'pubrel') qos = 1
 
@@ -386,7 +383,7 @@ function confirmation (packet, stream, opts) {
   }
 
   // properies mqtt 5
-  var propertiesData = null
+  let propertiesData = null
   if (version === 5) {
     // Confirm should not add empty property length with no properties (rfc 3.4.2.2.1)
     if (typeof properties === 'object') {
@@ -419,14 +416,14 @@ function confirmation (packet, stream, opts) {
 
 function subscribe (packet, stream, opts) {
   debug('subscribe: packet: ')
-  var version = opts ? opts.protocolVersion : 4
-  var settings = packet || {}
-  var dup = settings.dup ? protocol.DUP_MASK : 0
-  var id = settings.messageId
-  var subs = settings.subscriptions
-  var properties = settings.properties
+  const version = opts ? opts.protocolVersion : 4
+  const settings = packet || {}
+  const dup = settings.dup ? protocol.DUP_MASK : 0
+  const id = settings.messageId
+  const subs = settings.subscriptions
+  const properties = settings.properties
 
-  var length = 0
+  let length = 0
 
   // Check message ID
   if (typeof id !== 'number') {
@@ -435,7 +432,7 @@ function subscribe (packet, stream, opts) {
   } else length += 2
 
   // properies mqtt 5
-  var propertiesData = null
+  let propertiesData = null
   if (version === 5) {
     propertiesData = getProperties(stream, properties)
     if (!propertiesData) { return false }
@@ -444,9 +441,9 @@ function subscribe (packet, stream, opts) {
 
   // Check subscriptions
   if (typeof subs === 'object' && subs.length) {
-    for (var i = 0; i < subs.length; i += 1) {
-      var itopic = subs[i].topic
-      var iqos = subs[i].qos
+    for (let i = 0; i < subs.length; i += 1) {
+      const itopic = subs[i].topic
+      const iqos = subs[i].qos
 
       if (typeof itopic !== 'string') {
         stream.emit('error', new Error('Invalid subscriptions - invalid topic'))
@@ -458,17 +455,17 @@ function subscribe (packet, stream, opts) {
       }
 
       if (version === 5) {
-        var nl = subs[i].nl || false
+        const nl = subs[i].nl || false
         if (typeof nl !== 'boolean') {
           stream.emit('error', new Error('Invalid subscriptions - invalid No Local'))
           return false
         }
-        var rap = subs[i].rap || false
+        const rap = subs[i].rap || false
         if (typeof rap !== 'boolean') {
           stream.emit('error', new Error('Invalid subscriptions - invalid Retain as Published'))
           return false
         }
-        var rh = subs[i].rh || 0
+        const rh = subs[i].rh || 0
         if (typeof rh !== 'number' || rh > 2) {
           stream.emit('error', new Error('Invalid subscriptions - invalid Retain Handling'))
           return false
@@ -497,17 +494,16 @@ function subscribe (packet, stream, opts) {
     propertiesData.write()
   }
 
-  var result = true
+  let result = true
 
   // Generate subs
-  for (var j = 0; j < subs.length; j++) {
-    var sub = subs[j]
-    var jtopic = sub.topic
-    var jqos = sub.qos
-    var jnl = +sub.nl
-    var jrap = +sub.rap
-    var jrh = sub.rh
-    var joptions
+  for (const sub of subs) {
+    const jtopic = sub.topic
+    const jqos = sub.qos
+    const jnl = +sub.nl
+    const jrap = +sub.rap
+    const jrh = sub.rh
+    let joptions
 
     // Write topic string
     writeString(stream, jtopic)
@@ -527,12 +523,12 @@ function subscribe (packet, stream, opts) {
 }
 
 function suback (packet, stream, opts) {
-  var version = opts ? opts.protocolVersion : 4
-  var settings = packet || {}
-  var id = settings.messageId
-  var granted = settings.granted
-  var properties = settings.properties
-  var length = 0
+  const version = opts ? opts.protocolVersion : 4
+  const settings = packet || {}
+  const id = settings.messageId
+  const granted = settings.granted
+  const properties = settings.properties
+  let length = 0
 
   // Check message ID
   if (typeof id !== 'number') {
@@ -542,7 +538,7 @@ function suback (packet, stream, opts) {
 
   // Check granted qos vector
   if (typeof granted === 'object' && granted.length) {
-    for (var i = 0; i < granted.length; i += 1) {
+    for (let i = 0; i < granted.length; i += 1) {
       if (typeof granted[i] !== 'number') {
         stream.emit('error', new Error('Invalid qos vector'))
         return false
@@ -555,7 +551,7 @@ function suback (packet, stream, opts) {
   }
 
   // properies mqtt 5
-  var propertiesData = null
+  let propertiesData = null
   if (version === 5) {
     propertiesData = getPropertiesByMaximumPacketSize(stream, properties, opts, length)
     if (!propertiesData) { return false }
@@ -580,14 +576,14 @@ function suback (packet, stream, opts) {
 }
 
 function unsubscribe (packet, stream, opts) {
-  var version = opts ? opts.protocolVersion : 4
-  var settings = packet || {}
-  var id = settings.messageId
-  var dup = settings.dup ? protocol.DUP_MASK : 0
-  var unsubs = settings.unsubscriptions
-  var properties = settings.properties
+  const version = opts ? opts.protocolVersion : 4
+  const settings = packet || {}
+  const id = settings.messageId
+  const dup = settings.dup ? protocol.DUP_MASK : 0
+  const unsubs = settings.unsubscriptions
+  const properties = settings.properties
 
-  var length = 0
+  let length = 0
 
   // Check message ID
   if (typeof id !== 'number') {
@@ -598,7 +594,7 @@ function unsubscribe (packet, stream, opts) {
   }
   // Check unsubs
   if (typeof unsubs === 'object' && unsubs.length) {
-    for (var i = 0; i < unsubs.length; i += 1) {
+    for (let i = 0; i < unsubs.length; i += 1) {
       if (typeof unsubs[i] !== 'string') {
         stream.emit('error', new Error('Invalid unsubscriptions'))
         return false
@@ -610,7 +606,7 @@ function unsubscribe (packet, stream, opts) {
     return false
   }
   // properies mqtt 5
-  var propertiesData = null
+  let propertiesData = null
   if (version === 5) {
     propertiesData = getProperties(stream, properties)
     if (!propertiesData) { return false }
@@ -632,8 +628,8 @@ function unsubscribe (packet, stream, opts) {
   }
 
   // Unsubs
-  var result = true
-  for (var j = 0; j < unsubs.length; j++) {
+  let result = true
+  for (let j = 0; j < unsubs.length; j++) {
     result = writeString(stream, unsubs[j])
   }
 
@@ -641,16 +637,16 @@ function unsubscribe (packet, stream, opts) {
 }
 
 function unsuback (packet, stream, opts) {
-  var version = opts ? opts.protocolVersion : 4
-  var settings = packet || {}
-  var id = settings.messageId
-  var dup = settings.dup ? protocol.DUP_MASK : 0
-  var granted = settings.granted
-  var properties = settings.properties
-  var type = settings.cmd
-  var qos = 0
+  const version = opts ? opts.protocolVersion : 4
+  const settings = packet || {}
+  const id = settings.messageId
+  const dup = settings.dup ? protocol.DUP_MASK : 0
+  const granted = settings.granted
+  const properties = settings.properties
+  const type = settings.cmd
+  const qos = 0
 
-  var length = 2
+  let length = 2
 
   // Check message ID
   if (typeof id !== 'number') {
@@ -661,7 +657,7 @@ function unsuback (packet, stream, opts) {
   // Check granted
   if (version === 5) {
     if (typeof granted === 'object' && granted.length) {
-      for (var i = 0; i < granted.length; i += 1) {
+      for (let i = 0; i < granted.length; i += 1) {
         if (typeof granted[i] !== 'number') {
           stream.emit('error', new Error('Invalid qos vector'))
           return false
@@ -675,7 +671,7 @@ function unsuback (packet, stream, opts) {
   }
 
   // properies mqtt 5
-  var propertiesData = null
+  let propertiesData = null
   if (version === 5) {
     propertiesData = getPropertiesByMaximumPacketSize(stream, properties, opts, length)
     if (!propertiesData) { return false }
@@ -708,14 +704,14 @@ function emptyPacket (packet, stream, opts) {
 }
 
 function disconnect (packet, stream, opts) {
-  var version = opts ? opts.protocolVersion : 4
-  var settings = packet || {}
-  var reasonCode = settings.reasonCode
-  var properties = settings.properties
-  var length = version === 5 ? 1 : 0
+  const version = opts ? opts.protocolVersion : 4
+  const settings = packet || {}
+  const reasonCode = settings.reasonCode
+  const properties = settings.properties
+  let length = version === 5 ? 1 : 0
 
   // properies mqtt 5
-  var propertiesData = null
+  let propertiesData = null
   if (version === 5) {
     propertiesData = getPropertiesByMaximumPacketSize(stream, properties, opts, length)
     if (!propertiesData) { return false }
@@ -723,7 +719,7 @@ function disconnect (packet, stream, opts) {
   }
 
   // Header
-  stream.write(Buffer.from([protocol.codes['disconnect'] << 4]))
+  stream.write(Buffer.from([protocol.codes.disconnect << 4]))
 
   // Length
   writeVarByteInt(stream, length)
@@ -742,21 +738,21 @@ function disconnect (packet, stream, opts) {
 }
 
 function auth (packet, stream, opts) {
-  var version = opts ? opts.protocolVersion : 4
-  var settings = packet || {}
-  var reasonCode = settings.reasonCode
-  var properties = settings.properties
-  var length = version === 5 ? 1 : 0
+  const version = opts ? opts.protocolVersion : 4
+  const settings = packet || {}
+  const reasonCode = settings.reasonCode
+  const properties = settings.properties
+  let length = version === 5 ? 1 : 0
 
   if (version !== 5) stream.emit('error', new Error('Invalid mqtt version for auth packet'))
 
   // properies mqtt 5
-  var propertiesData = getPropertiesByMaximumPacketSize(stream, properties, opts, length)
+  const propertiesData = getPropertiesByMaximumPacketSize(stream, properties, opts, length)
   if (!propertiesData) { return false }
   length += propertiesData.length
 
   // Header
-  stream.write(Buffer.from([protocol.codes['auth'] << 4]))
+  stream.write(Buffer.from([protocol.codes.auth << 4]))
 
   // Length
   writeVarByteInt(stream, length)
@@ -782,12 +778,12 @@ function auth (packet, stream, opts) {
  * @api private
  */
 
-var varByteIntCache = {}
+const varByteIntCache = {}
 function writeVarByteInt (stream, num) {
-  var buffer = varByteIntCache[num]
+  let buffer = varByteIntCache[num]
 
   if (!buffer) {
-    buffer = genBufVariableByteInt(num).data
+    buffer = genBufVariableByteInt(num)
     if (num < 16384) varByteIntCache[num] = buffer
   }
   debug('writeVarByteInt: writing to stream: %o', buffer)
@@ -806,7 +802,7 @@ function writeVarByteInt (stream, num) {
  */
 
 function writeString (stream, string) {
-  var strlen = Buffer.byteLength(string)
+  const strlen = Buffer.byteLength(string)
   writeNumber(stream, strlen)
 
   debug('writeString: %s', string)
@@ -844,12 +840,12 @@ function writeNumberCached (stream, number) {
   return stream.write(numCache[number])
 }
 function writeNumberGenerated (stream, number) {
-  var generatedNumber = generateNumber(number)
+  const generatedNumber = generateNumber(number)
   debug('writeNumberGenerated: %o', generatedNumber)
   return stream.write(generatedNumber)
 }
 function write4ByteNumber (stream, number) {
-  var generated4ByteBuffer = generate4ByteBuffer(number)
+  const generated4ByteBuffer = generate4ByteBuffer(number)
   debug('write4ByteNumber: %o', generated4ByteBuffer)
   return stream.write(generated4ByteBuffer)
 }
@@ -875,19 +871,19 @@ function getProperties (stream, properties) {
   if (typeof properties !== 'object' || properties.length != null) {
     return {
       length: 1,
-      write: function () {
+      write () {
         writeProperties(stream, {}, 0)
       }
     }
   }
-  var propertiesLength = 0
+  let propertiesLength = 0
   function getLengthProperty (name, value) {
-    var type = protocol.propertiesTypes[name]
-    var length = 0
+    const type = protocol.propertiesTypes[name]
+    let length = 0
     switch (type) {
       case 'byte': {
         if (typeof value !== 'boolean') {
-          stream.emit('error', new Error('Invalid ' + name + ': ' + value))
+          stream.emit('error', new Error(`Invalid ${name}: ${value}`))
           return false
         }
         length += 1 + 1
@@ -895,7 +891,7 @@ function getProperties (stream, properties) {
       }
       case 'int8': {
         if (typeof value !== 'number' || value < 0 || value > 0xff) {
-          stream.emit('error', new Error('Invalid ' + name + ': ' + value))
+          stream.emit('error', new Error(`Invalid ${name}: ${value}`))
           return false
         }
         length += 1 + 1
@@ -903,7 +899,7 @@ function getProperties (stream, properties) {
       }
       case 'binary': {
         if (value && value === null) {
-          stream.emit('error', new Error('Invalid ' + name + ': ' + value))
+          stream.emit('error', new Error(`Invalid ${name}: ${value}`))
           return false
         }
         length += 1 + Buffer.byteLength(value) + 2
@@ -911,7 +907,7 @@ function getProperties (stream, properties) {
       }
       case 'int16': {
         if (typeof value !== 'number' || value < 0 || value > 0xffff) {
-          stream.emit('error', new Error('Invalid ' + name + ': ' + value))
+          stream.emit('error', new Error(`Invalid ${name}: ${value}`))
           return false
         }
         length += 1 + 2
@@ -919,23 +915,24 @@ function getProperties (stream, properties) {
       }
       case 'int32': {
         if (typeof value !== 'number' || value < 0 || value > 0xffffffff) {
-          stream.emit('error', new Error('Invalid ' + name + ': ' + value))
+          stream.emit('error', new Error(`Invalid ${name}: ${value}`))
           return false
         }
         length += 1 + 4
         break
       }
       case 'var': {
-        if (typeof value !== 'number' || value < 0 || value > 0xffffffff) {
-          stream.emit('error', new Error('Invalid ' + name + ': ' + value))
+        // var byte integer is max 24 bits packed in 32 bits
+        if (typeof value !== 'number' || value < 0 || value > 0x0fffffff) {
+          stream.emit('error', new Error(`Invalid ${name}: ${value}`))
           return false
         }
-        length += 1 + genBufVariableByteInt(value).length
+        length += 1 + Buffer.byteLength(genBufVariableByteInt(value))
         break
       }
       case 'string': {
         if (typeof value !== 'string') {
-          stream.emit('error', new Error('Invalid ' + name + ': ' + value))
+          stream.emit('error', new Error(`Invalid ${name}: ${value}`))
           return false
         }
         length += 1 + 2 + Buffer.byteLength(value.toString())
@@ -943,13 +940,13 @@ function getProperties (stream, properties) {
       }
       case 'pair': {
         if (typeof value !== 'object') {
-          stream.emit('error', new Error('Invalid ' + name + ': ' + value))
+          stream.emit('error', new Error(`Invalid ${name}: ${value}`))
           return false
         }
-        length += Object.getOwnPropertyNames(value).reduce(function (result, name) {
-          var currentValue = value[name]
+        length += Object.getOwnPropertyNames(value).reduce((result, name) => {
+          const currentValue = value[name]
           if (Array.isArray(currentValue)) {
-            result += currentValue.reduce(function (currentLength, value) {
+            result += currentValue.reduce((currentLength, value) => {
               currentLength += 1 + 2 + Buffer.byteLength(name.toString()) + 2 + Buffer.byteLength(value.toString())
               return currentLength
             }, 0)
@@ -961,19 +958,19 @@ function getProperties (stream, properties) {
         break
       }
       default: {
-        stream.emit('error', new Error('Invalid property ' + name + ': ' + value))
+        stream.emit('error', new Error(`Invalid property ${name}: ${value}`))
         return false
       }
     }
     return length
   }
   if (properties) {
-    for (var propName in properties) {
-      var propLength = 0
-      var propValueLength = 0
-      var propValue = properties[propName]
+    for (const propName in properties) {
+      let propLength = 0
+      let propValueLength = 0
+      const propValue = properties[propName]
       if (Array.isArray(propValue)) {
-        for (var valueIndex = 0; valueIndex < propValue.length; valueIndex++) {
+        for (let valueIndex = 0; valueIndex < propValue.length; valueIndex++) {
           propValueLength = getLengthProperty(propName, propValue[valueIndex])
           if (!propValueLength) { return false }
           propLength += propValueLength
@@ -987,24 +984,24 @@ function getProperties (stream, properties) {
       propertiesLength += propLength
     }
   }
-  var propertiesLengthLength = genBufVariableByteInt(propertiesLength).length
+  const propertiesLengthLength = Buffer.byteLength(genBufVariableByteInt(propertiesLength))
 
   return {
     length: propertiesLengthLength + propertiesLength,
-    write: function () {
+    write () {
       writeProperties(stream, properties, propertiesLength)
     }
   }
 }
 
 function getPropertiesByMaximumPacketSize (stream, properties, opts, length) {
-  var mayEmptyProps = ['reasonString', 'userProperties']
-  var maximumPacketSize = opts && opts.properties && opts.properties.maximumPacketSize ? opts.properties.maximumPacketSize : 0
+  const mayEmptyProps = ['reasonString', 'userProperties']
+  const maximumPacketSize = opts && opts.properties && opts.properties.maximumPacketSize ? opts.properties.maximumPacketSize : 0
 
-  var propertiesData = getProperties(stream, properties)
+  let propertiesData = getProperties(stream, properties)
   if (maximumPacketSize) {
     while (length + propertiesData.length > maximumPacketSize) {
-      var currentMayEmptyProp = mayEmptyProps.shift()
+      const currentMayEmptyProp = mayEmptyProps.shift()
       if (currentMayEmptyProp && properties[currentMayEmptyProp]) {
         delete properties[currentMayEmptyProp]
         propertiesData = getProperties(stream, properties)
@@ -1017,7 +1014,7 @@ function getPropertiesByMaximumPacketSize (stream, properties, opts, length) {
 }
 
 function writeProperty (stream, propName, value) {
-  var type = protocol.propertiesTypes[propName]
+  const type = protocol.propertiesTypes[propName]
   switch (type) {
     case 'byte': {
       stream.write(Buffer.from([protocol.properties[propName]]))
@@ -1055,10 +1052,10 @@ function writeProperty (stream, propName, value) {
       break
     }
     case 'pair': {
-      Object.getOwnPropertyNames(value).forEach(function (name) {
-        var currentValue = value[name]
+      Object.getOwnPropertyNames(value).forEach(name => {
+        const currentValue = value[name]
         if (Array.isArray(currentValue)) {
-          currentValue.forEach(function (value) {
+          currentValue.forEach(value => {
             stream.write(Buffer.from([protocol.properties[propName]]))
             writeStringPair(stream, name.toString(), value.toString())
           })
@@ -1070,7 +1067,7 @@ function writeProperty (stream, propName, value) {
       break
     }
     default: {
-      stream.emit('error', new Error('Invalid property ' + propName + ' value: ' + value))
+      stream.emit('error', new Error(`Invalid property ${propName} value: ${value}`))
       return false
     }
   }
@@ -1079,11 +1076,11 @@ function writeProperty (stream, propName, value) {
 function writeProperties (stream, properties, propertiesLength) {
   /* write properties to stream */
   writeVarByteInt(stream, propertiesLength)
-  for (var propName in properties) {
-    if (properties.hasOwnProperty(propName) && properties[propName] !== null) {
-      var value = properties[propName]
+  for (const propName in properties) {
+    if (Object.prototype.hasOwnProperty.call(properties, propName) && properties[propName] !== null) {
+      const value = properties[propName]
       if (Array.isArray(value)) {
-        for (var valueIndex = 0; valueIndex < value.length; valueIndex++) {
+        for (let valueIndex = 0; valueIndex < value.length; valueIndex++) {
           writeProperty(stream, propName, value[valueIndex])
         }
       } else {
